@@ -152,7 +152,7 @@ void WriteDetailIcon(struct item *direntry)
   XCopyArea(GetDisplay(),direntry->mini,direntry->Iconwindow,gch,
 		0,0,14,14,96,0);
   XSetClipMask(GetDisplay(),gch,None);
-  if (direntry->type>=2)
+  if ( (direntry->type>=2) && (GetLinkIcon()==True) )
       XCopyArea(GetDisplay(),littlelinkpix,direntry->Iconwindow,gch,
 		0,0,7,8,104,7);
   XDrawLine(GetDisplay(),direntry->Iconwindow,gch,0,0,0,14);
@@ -251,6 +251,7 @@ void CreateIconWithDirentry(struct item *direntry,int newicon,int plusmore)
       backgroundpixmap=noicon;
       isxvpic=False;
     }
+    // Inverse selection
     if (direntry->mark==False) {
       XSetBackground(GetDisplay(),gch,GetBGColor());
       XSetForeground(GetDisplay(),gch,GetFGColor());
@@ -272,6 +273,8 @@ void CreateIconWithDirentry(struct item *direntry,int newicon,int plusmore)
     } 
     XGetGeometry(GetDisplay(),backgroundpixmap,&root,&x,&y,&width,&height,
 		 &dummy,&depth);
+
+    /* calc text size */
     twidth=XTextWidth(fontst,text,strlen(text));
     if (twidth<width) {
       xpostext=(width-twidth)/2;
@@ -284,12 +287,17 @@ void CreateIconWithDirentry(struct item *direntry,int newicon,int plusmore)
     }
     if (direntry->type>=2 || GetIsDesktop()==True)
       nwidth=nwidth+7;
-      /*nwidth=nwidth+11;*/
     if (plusmore==True)
       nwidth=nwidth+8+XTextWidth(fontst,"+ more",strlen("+ more"));
+    
+    /* Create the pixmap that will be the (background-)image of 
+       the iconwindow */
     backgroundpixmap2=
       XCreatePixmap(GetDisplay(),direntry->Iconwindow,
 	            nwidth,height+2+fontst->ascent+fontst->descent,depth);
+
+    /* if icon is selected init the goal pixmap with 1 to invert 
+       iconpixmap with xor*/
     if (direntry->mark==True) {
       XFillRectangle(GetDisplay(),backgroundpixmap2,gch,
                      xposicon,0,width,height);
@@ -298,53 +306,67 @@ void CreateIconWithDirentry(struct item *direntry,int newicon,int plusmore)
     XCopyArea(GetDisplay(),backgroundpixmap,backgroundpixmap2,gch,
               0,0,width,height,xposicon,0);
     XSetFunction(GetDisplay(),gch,GXcopy);
-    if (direntry->type>=2) 
+    
+    if ( (direntry->type>=2) && (GetLinkIcon()==True) )
     XCopyArea(GetDisplay(),littlelinkpix,backgroundpixmap2,gch,
               0,0,7,8,xpostext+twidth,height-2);
-    /*XCopyArea(GetDisplay(),linkpix,backgroundpixmap2,gch,
-              0,0,11,11,xpostext+twidth,height-5);*/
+    
+    /*this can be deleted because there is no cache for xvpics*/
     if (isxvpic==True)
       XFreePixmap(GetDisplay(),backgroundpixmap);
+    
+    /* Draw Text below the icon */
     XDrawImageString(GetDisplay(),backgroundpixmap2,gch,
                      xpostext,height+2+fontst->ascent,text,strlen(text));
     if (plusmore==True)
       XDrawImageString(GetDisplay(),backgroundpixmap2,gch,
 		       xpostext+twidth+8,height+2+fontst->ascent,
 		       "+ more",strlen("+ more"));
+		       
+    /* set the image of the icon-window with the drawn pixmap */
     XSetWindowBackgroundPixmap(GetDisplay(),direntry->Iconwindow,
                                backgroundpixmap2);
+
+    /* create the shape pixmap (1bpp)*/
     shapepixmap2=
       XCreatePixmap(GetDisplay(),direntry->Iconwindow,
 	            nwidth,height+2+fontst->ascent+fontst->descent,1);
     if (gc==None)
       gc=XCreateGC(GetDisplay(),shapepixmap2,0,0);
     XSetForeground(GetDisplay(),gc,0);
+    /* erase the pixmap */
     XFillRectangle(GetDisplay(),shapepixmap2,gc,0,0,
 		   nwidth,height+2+fontst->ascent+fontst->descent);
     XSetBackground(GetDisplay(),gc,0);
     XSetForeground(GetDisplay(),gc,1);
+    /* if there is no shapepixmap assume full rectangle icon */
     if (shapepixmap==0)
       XFillRectangle(GetDisplay(),shapepixmap2,gc,xposicon,0,width,height);
     else
       XCopyArea(GetDisplay(),shapepixmap,shapepixmap2,gc,0,0,width,height,
 		xposicon,0);
+    /* Draw shape of icon text */
     XFillRectangle(GetDisplay(),shapepixmap2,gc,
                    xpostext,height+2,twidth,fontst->ascent+fontst->descent);
     if (plusmore==True)
       XFillRectangle(GetDisplay(),shapepixmap2,gc,xpostext+twidth+8,height+2,
                      XTextWidth(fontst,"+ more",strlen("+ more")),
 		     fontst->ascent+fontst->descent);
-    if (direntry->type>=2)
+		     
+    if ( (direntry->type>=2) && (GetLinkIcon()==True) )
       XFillRectangle(GetDisplay(),shapepixmap2,gc,
                      xpostext+twidth,height-2,7,8);
-      /*XFillRectangle(GetDisplay(),shapepixmap2,gc,
-                     xpostext+twidth,height-5,11,11);*/
+		     
+    /* set the shape of the icon-window with the drawn shape pixmap */
     XShapeCombineMask(GetDisplay(),direntry->Iconwindow,ShapeBounding,0,0, 
 		      shapepixmap2,ShapeSet);
     
+    /* X11 frees lates automatically the pixmap if its window is destroyed.
+       Now the pixmap is used and will not be destroyed. */
     XFreePixmap(GetDisplay(),backgroundpixmap2);
     XFreePixmap(GetDisplay(),shapepixmap2);
     
+    /* resize, position and display the window */
     if (pos==NULL) {
       PositionArrange(direntry,nwidth,height+2+fontst->ascent+fontst->descent);
       SendFileInfoToDesktop(fullname,NULL,icon,start);
@@ -440,7 +462,7 @@ void CreateIconWithDirentry(struct item *direntry,int newicon,int plusmore)
     if (shapepixmap!=0)
       XCopyArea(GetDisplay(),shapepixmap,shapepixmap2,gc,
 		0,0,14,14,1,(2+fontst->ascent+fontst->descent)/2-7);
-    if (direntry->type>=2) {
+    if ( (direntry->type>=2) && (GetLinkIcon()==True) ) {
       XCopyArea(GetDisplay(),littlelinkpix,backgroundpixmap2,gch,
 		0,0,7,8,9,(2+fontst->ascent+fontst->descent)/2);
       XFillRectangle(GetDisplay(),shapepixmap2,gc,
