@@ -17,30 +17,23 @@ struct item {
   char *filename;
   struct stat info;
   int type; /* 0 file 1 folder 2 linkfile 3 linkfolder */
-  int mark; 
-  struct item *NextItem;
+  int mark; /*BOOL*/
+  struct item *nextitem;
+  struct item *subtree;
+  int horizontal;
   Window Iconwindow;
+  Window Inputonly;
   Pixmap mini;
   Pixmap minis;
-};
-
-struct tree {
-  struct item *ThisItem;
-  struct tree *subtree;
-  struct tree *nexttree;
-  int initalized;/*dotree was called with this argument*/
-  int expanded;
-  int abletoexpand; /*if subtree=NULL then False*/
   Window Expandbutton;
-  Window Expandline;
+  Window Connectline;
+  Window ExpandlineV;
+  Window ExpandlineH;
+  Window Switchbutton;
 };
 
 struct item *GetDirectory(char *filepath);
 
-struct tree *GetFirstTree();
-
-void DoTree(struct tree *treeinfo);
-
 void GetLinkNameWithoutLast(char **text);
 
 void GetLinkName(char **text);
