@@ -22,7 +22,10 @@
 #include <string.h>
 #include "global.h"
 
-#include "includepixmaps/title.xpm"
+#include "includepixmaps/dfmlogo.xpm"
+
+#include <libintl.h>
+#define _(string) gettext(string)
 
 int exitvar=0;
 GtkWidget *obj_ret;
@@ -101,7 +104,7 @@ void Info()
   GdkBitmap* mask;
 
   window = gtk_window_new (GTK_WINDOW_DIALOG);
-  gtk_window_set_title(GTK_WINDOW(window), "Control");
+  gtk_window_set_title(GTK_WINDOW(window), _("Control"));
   gtk_window_position(GTK_WINDOW(window),GTK_WIN_POS_CENTER);
   gtk_container_border_width(GTK_CONTAINER(window), 10);
   
@@ -109,7 +112,7 @@ void Info()
   gtk_container_add(GTK_CONTAINER(window),vbox);
   gtk_widget_show(vbox);
   
-  pixmap = gdk_pixmap_create_from_xpm_d(window->window,&mask,NULL,title_xpm);
+  pixmap = gdk_pixmap_create_from_xpm_d(window->window,&mask,NULL,dfmlogo_xpm);
   logo = gtk_pixmap_new(pixmap, mask); 
   gtk_box_pack_start(GTK_BOX(vbox), logo, TRUE, TRUE, 0);
   gtk_widget_show(logo);
@@ -161,7 +164,7 @@ int Question(char *text)
   GtkWidget *label;
 
   window = gtk_window_new (GTK_WINDOW_DIALOG);
-  gtk_window_set_title(GTK_WINDOW(window), "Control");
+  gtk_window_set_title(GTK_WINDOW(window), _("Control"));
   gtk_window_position(GTK_WINDOW(window),GTK_WIN_POS_CENTER);
   gtk_container_border_width(GTK_CONTAINER(window), 10);
   
@@ -178,13 +181,13 @@ int Question(char *text)
   gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, FALSE, 0);
   gtk_widget_show(hbox);
   
-  button = gtk_button_new_with_label ("Yes");
+  button = gtk_button_new_with_label (_("Yes"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (YesCallback), (gpointer) "Yes");
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
-  button = gtk_button_new_with_label ("Cancel");
+  button = gtk_button_new_with_label (_("Cancel"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (ExitCallback), (gpointer) "Cancel");
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
@@ -206,7 +209,7 @@ void Message(char *text)
   GtkWidget *label;
 
   window = gtk_window_new (GTK_WINDOW_DIALOG);
-  gtk_window_set_title(GTK_WINDOW(window), "DFM Warning");
+  gtk_window_set_title(GTK_WINDOW(window), _("DFM Warning"));
   gtk_window_position(GTK_WINDOW(window),GTK_WIN_POS_CENTER);
   gtk_container_border_width(GTK_CONTAINER(window), 10);
   
@@ -219,7 +222,7 @@ void Message(char *text)
   gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, FALSE, 0);
   gtk_widget_show(label);
 
-  button = gtk_button_new_with_label ("Noticed");
+  button = gtk_button_new_with_label (_("Noticed"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (YesCallback), (gpointer) "Yes");
   gtk_box_pack_start(GTK_BOX(vbox), button, TRUE, TRUE, 0);
@@ -259,7 +262,7 @@ int OverwriteQuestion(char *filename,char **rename_to)
   gtk_box_pack_start(GTK_BOX(vbox), entry, TRUE, TRUE, 0);
   gtk_widget_show(entry);
 
-  label = gtk_label_new ("Already exist! Delete this file before copying ... ?");
+  label = gtk_label_new (_("Already exist! Delete this file before copying... ?"));
   gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
   gtk_widget_show(label);
 
@@ -267,25 +270,25 @@ int OverwriteQuestion(char *filename,char **rename_to)
   gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, FALSE, 0);
   gtk_widget_show(hbox);
 
-  button = gtk_button_new_with_label ("Yes");
+  button = gtk_button_new_with_label (_("Yes"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (YesCallback), (gpointer) "Yes");
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
-  button = gtk_button_new_with_label ("All");
+  button = gtk_button_new_with_label (_("All"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (AllCallback), (gpointer) "All");
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
-  button = gtk_button_new_with_label ("No");
+  button = gtk_button_new_with_label (_("No, next File"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (NoCallback), (gpointer) "No");
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
-  label = gtk_label_new ("... or rename source to");
+  label = gtk_label_new (_("... or rename source to"));
   gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
   gtk_widget_show(label);
 
@@ -304,13 +307,13 @@ int OverwriteQuestion(char *filename,char **rename_to)
   gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, FALSE, 0);
   gtk_widget_show(hbox);
 
-  button = gtk_button_new_with_label ("Rename");
+  button = gtk_button_new_with_label (_("Rename"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (RenameCallback), (gpointer) rename_to);
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
-  button = gtk_button_new_with_label ("Cancel");
+  button = gtk_button_new_with_label (_("Cancel"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (ExitCallback), (gpointer) "Cancel");
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
@@ -335,7 +338,7 @@ void NewProgram()
   char *text;
 
   window = gtk_window_new (GTK_WINDOW_DIALOG);
-  gtk_window_set_title(GTK_WINDOW(window), "Control");
+  gtk_window_set_title(GTK_WINDOW(window), _("Control"));
   gtk_window_position(GTK_WINDOW(window),GTK_WIN_POS_CENTER);
   gtk_container_border_width(GTK_CONTAINER(window), 10);
 
@@ -347,7 +350,7 @@ void NewProgram()
   gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, FALSE, 0);
   gtk_widget_show(hbox);
 
-  label = gtk_label_new ("Program");
+  label = gtk_label_new (_("Program"));
   gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
   gtk_widget_show(label);
 
@@ -359,13 +362,13 @@ void NewProgram()
   gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, FALSE, 0);
   gtk_widget_show(hbox);
 
-  button = gtk_button_new_with_label ("Create");
+  button = gtk_button_new_with_label (_("Create"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (RenameCallback), (gpointer) &text);
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
-  button = gtk_button_new_with_label ("Cancel");
+  button = gtk_button_new_with_label (_("Cancel"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (ExitCallback), (gpointer) "Cancel");
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
@@ -395,7 +398,7 @@ void NewFile()
   char *text;
 
   window = gtk_window_new (GTK_WINDOW_DIALOG);
-  gtk_window_set_title(GTK_WINDOW(window), "Control");
+  gtk_window_set_title(GTK_WINDOW(window), _("Control"));
   gtk_window_position(GTK_WINDOW(window),GTK_WIN_POS_CENTER);
   gtk_container_border_width(GTK_CONTAINER(window), 10);
 
@@ -407,7 +410,7 @@ void NewFile()
   gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, FALSE, 0);
   gtk_widget_show(hbox);
 
-  label = gtk_label_new ("File");
+  label = gtk_label_new (_("File"));
   gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
   gtk_widget_show(label);
 
@@ -419,13 +422,13 @@ void NewFile()
   gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, FALSE, 0);
   gtk_widget_show(hbox);
 
-  button = gtk_button_new_with_label ("Create");
+  button = gtk_button_new_with_label (_("Create"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (RenameCallback), (gpointer) &text);
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
-  button = gtk_button_new_with_label ("Cancel");
+  button = gtk_button_new_with_label (_("Cancel"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (ExitCallback), (gpointer) "Cancel");
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
@@ -455,7 +458,7 @@ void NewFolder()
   char *text;
 
   window = gtk_window_new (GTK_WINDOW_DIALOG);
-  gtk_window_set_title(GTK_WINDOW(window), "Control");
+  gtk_window_set_title(GTK_WINDOW(window), _("Control"));
   gtk_window_position(GTK_WINDOW(window),GTK_WIN_POS_CENTER);
   gtk_container_border_width(GTK_CONTAINER(window), 10);
 
@@ -467,7 +470,7 @@ void NewFolder()
   gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, FALSE, 0);
   gtk_widget_show(hbox);
 
-  label = gtk_label_new ("Folder");
+  label = gtk_label_new (_("Folder"));
   gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
   gtk_widget_show(label);
 
@@ -479,13 +482,13 @@ void NewFolder()
   gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, FALSE, 0);
   gtk_widget_show(hbox);
 
-  button = gtk_button_new_with_label ("Create");
+  button = gtk_button_new_with_label (_("Create"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (RenameCallback), (gpointer) &text);
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
-  button = gtk_button_new_with_label ("Cancel");
+  button = gtk_button_new_with_label (_("Cancel"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (ExitCallback), (gpointer) "Cancel");
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
@@ -514,7 +517,7 @@ int EraseQuestion(char *filename)
   GtkWidget *button;
 
   window = gtk_window_new (GTK_WINDOW_DIALOG);
-  gtk_window_set_title(GTK_WINDOW(window), "Control");
+  gtk_window_set_title(GTK_WINDOW(window), _("Control"));
   gtk_window_position(GTK_WINDOW(window),GTK_WIN_POS_CENTER);
   gtk_container_border_width(GTK_CONTAINER(window), 10);
 
@@ -522,7 +525,7 @@ int EraseQuestion(char *filename)
   gtk_container_add(GTK_CONTAINER(window),vbox);
   gtk_widget_show(vbox);
 
-  label = gtk_label_new ("Really delete this file?");
+  label = gtk_label_new (_("Really delete this file?"));
   gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, FALSE, 0);
   gtk_widget_show(label);
 
@@ -536,25 +539,25 @@ int EraseQuestion(char *filename)
   gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, FALSE, 0);
   gtk_widget_show(hbox);
 
-  button = gtk_button_new_with_label ("Yes");
+  button = gtk_button_new_with_label (_("Yes"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (YesCallback), (gpointer) "Yes");
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
-  button = gtk_button_new_with_label ("Cancel");
+  button = gtk_button_new_with_label (_("Cancel"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (ExitCallback), (gpointer) "Cancel");
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
-  button = gtk_button_new_with_label ("All");
+  button = gtk_button_new_with_label (_("All"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (AllCallback), (gpointer) "All");
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
-  button = gtk_button_new_with_label ("No");
+  button = gtk_button_new_with_label (_("No"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (NoCallback), (gpointer) "No");
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
@@ -578,7 +581,7 @@ int EraseQuestionOnDifferent(char *filename)
   GtkWidget *button;
 
   window = gtk_window_new (GTK_WINDOW_DIALOG);
-  gtk_window_set_title(GTK_WINDOW(window), "Control");
+  gtk_window_set_title(GTK_WINDOW(window), _("Control"));
   gtk_window_position(GTK_WINDOW(window),GTK_WIN_POS_CENTER);
   gtk_container_border_width(GTK_CONTAINER(window), 10);
 
@@ -586,11 +589,11 @@ int EraseQuestionOnDifferent(char *filename)
   gtk_container_add(GTK_CONTAINER(window),vbox);
   gtk_widget_show(vbox);
 
-  label = gtk_label_new ("Some files aren't copied correctly! There are differences!");
+  label = gtk_label_new (_("Some files aren't copied correctly! There are differences!"));
   gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, FALSE, 0);
   gtk_widget_show(label);
 
-  label = gtk_label_new ("Really delete this orginal?");
+  label = gtk_label_new (_("Really delete this orginal?"));
   gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, FALSE, 0);
   gtk_widget_show(label);
 
@@ -604,25 +607,25 @@ int EraseQuestionOnDifferent(char *filename)
   gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, FALSE, 0);
   gtk_widget_show(hbox);
 
-  button = gtk_button_new_with_label ("Yes");
+  button = gtk_button_new_with_label (_("Yes"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (YesCallback), (gpointer) "Yes");
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
-  button = gtk_button_new_with_label ("Cancel");
+  button = gtk_button_new_with_label (_("Cancel"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (ExitCallback), (gpointer) "Cancel");
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
-  button = gtk_button_new_with_label ("All");
+  button = gtk_button_new_with_label (_("All"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (AllCallback), (gpointer) "All");
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
   gtk_widget_show(button);
 
-  button = gtk_button_new_with_label ("No");
+  button = gtk_button_new_with_label (_("No"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (NoCallback), (gpointer) "No");
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
