@@ -505,6 +505,22 @@ void SetAutoSave(int status)
   free(text);
 }
 
+void SetLinkIcon(int status)
+{
+  char* text; 
+  Atom namedatom;
+
+  text=malloc(strlen("_DFMLINKICON")+1);
+  strcpy(text,"_DFMLINKICON");
+  namedatom=XInternAtom(GetDisplay(),text,False);
+  if (status==False) {
+    XChangeProperty(GetDisplay(),deskwin,namedatom,XA_STRING,8,PropModeReplace,
+		    (unsigned char*)"False",strlen("False"));
+  } else
+    XDeleteProperty(GetDisplay(),deskwin,namedatom);
+  free(text);
+}
+
 int GetAutoSave()
 {
   char* text;
@@ -537,6 +553,38 @@ int GetAutoSave()
   return(back);  
 }
 
+int GetLinkIcon()
+{
+  char* text;
+  char* backs;
+  Atom namedatom;
+  Atom dummyatom;
+  int dummyformat;
+  unsigned char *propret;
+  unsigned long length;
+  unsigned long dummy;
+  int back=True;
+  text=malloc(strlen("_DFMLINKICON")+1);
+  strcpy(text,"_DFMLINKICON");
+  if ((namedatom=XInternAtom(GetDisplay(),text,True))==0) 
+    return(True);
+  else {
+    XGetWindowProperty(GetDisplay(),deskwin,namedatom,0,8192,False,XA_STRING,
+		       &dummyatom,&dummyformat,&length,&dummy,&propret);
+    if (length!=0){
+      backs=malloc(length+1);
+      strncpy(backs,(char*)propret,length);
+      (backs)[length]=0;
+      if (strcmp("False",backs)==0)
+	back=False;
+      XFree(propret);
+      free(backs);
+    }
+  }
+  free(text);
+  return(back);  
+}
+
 void SetMainBackground(int status)
 {
   char* text; 
@@ -843,6 +891,17 @@ void SaveFileInfoFromDesktop()
 	  dfmgzprint(pfSave,name,text);
 	  free(text);
 	}
+      } else if (strncmp(name,"_DFMLINKICON",strlen("_DFMLINKICON"))==0) {
+	XGetWindowProperty(GetDisplay(),deskwin,properties[i],0,8192,False,XA_STRING,
+			   &dummyatom,&dummyformat,&length,&dummy,&propret);
+	if (length!=0){
+	  text=malloc(length+1);
+	  strncpy(text,(char*)propret,length);
+	  text[length]=0;
+	  XFree(propret);
+	  dfmgzprint(pfSave,name,text);
+	  free(text);
+	}
       } else if (strncmp(name,"_DFMAUTOSAVE",strlen("_DFMMAINBACK"))==0) {
 	XGetWindowProperty(GetDisplay(),deskwin,properties[i],0,8192,False,XA_STRING,
 			   &dummyatom,&dummyformat,&length,&dummy,&propret);
