@@ -449,7 +449,10 @@ void Menu(char* name,int x,int y,int inwindow)
               mnt2=getmntent(pfile2);
               text3=NULL;
 	      if (mnt2)
-	        text3=strstr(mnt->mnt_dir,text2);
+	      {
+		if (strcmp(mnt2->mnt_dir,text2)==0)
+		    text3=text2;
+		}
             } while (text3==NULL && mnt2!=NULL);
 	    if (text3==NULL) {
 	      text3=malloc(strlen("mount ")+strlen(text2)+1);
