@@ -56,6 +56,7 @@ GtkWidget *objdesk;
 GtkWidget *objtimer;
 GtkWidget *objcache;
 GtkWidget *objsave;
+GtkWidget *objlink;
 GtkWidget *objfont;
 GtkWidget *objdefback;
 GtkWidget *winhide;
@@ -490,6 +491,11 @@ void MainWindowApplyCallback(GtkWidget *widget, gpointer data)
   else {
     SetAutoSave(False);
   }  
+  if (GTK_TOGGLE_BUTTON(objlink)->active)  
+    SetLinkIcon(True);
+  else {
+    SetLinkIcon(False);
+  }  
   test = gtk_entry_get_text(GTK_ENTRY(objax));
   if (test[0]==0)   
     strcat(text1,"5");
@@ -810,11 +816,17 @@ void MainWindowOptions(int argc,char *argv[])
   sprintf(wbackcol,"# %d %d %d",r4,g4,b4);
   
   objsave = gtk_check_button_new_with_label ("Save positions/info continously");
-  mygtk_setposition(table,objsave,370,340,225,30);
+  mygtk_setposition(table,objsave,370,335,225,30);
   if (GetAutoSave()==True) {
     gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(objsave),True);
   }
   
+  objlink = gtk_check_button_new_with_label ("Show link arrow in icons");
+  mygtk_setposition(table,objlink,370,360,225,30);
+  if (GetLinkIcon()==True) {
+    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(objlink),True);
+  }
+
   obj = gtk_label_new ("Background");
   mygtk_setposition(table,obj,280,325,80,20);
 
