@@ -14,7 +14,7 @@ void ShellWindowInfo(char *namet,char *names,char *named,int this);
 
 int ShellWindowUpdate();
 
-int ShellWindowDoIt(char** argv,int cont);
+int ShellWindowDoIt(char** argv,int cont,char *path);
 
 void ShellWindowDestroy();
 
